"""Minimal wrapper for executing callable sequences in order."""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/13_utils_workflow.ipynb.

# %% auto 0
__all__ = ['Workflow']

# %% ../nbs/13_utils_workflow.ipynb 2
from fastcore.utils import *
from typing import Callable, List

# %% ../nbs/13_utils_workflow.ipynb 5
class Workflow:
    """Execute a list of callables sequentially. Minimal wrapper for code readability."""
    
    def __init__(self, steps: List[Callable]):
        """Initialize workflow with list of callable steps"""
        self.steps = steps
    
    def execute(self):
        """Execute all steps in order"""
        for step in self.steps:
            step()
